/*******************************************************************************
* File Name: CapSense_2_SMS.h
* Version 2.40
*
* Description:
*  This file provides the declarations of the wrapper between the CapSense CSD component
*  and Auto Tuning library.
*
* Note:
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#if !defined(CY_CAPSENSE_CSD_SMS_CapSense_2_H)
#define CY_CAPSENSE_CSD_SMS_CapSense_2_H

#include "CapSense_2.h"
#include "CapSense_2_PVT.h"

#if(0u != CapSense_2_CSHL_API_GENERATE)
    #include "CapSense_2_CSHL.h"
#endif /* (0u != CapSense_2_CSHL_API_GENERATE) */

#define CapSense_2_PRESCALERS_TBL_SIZE        (16u)

#define CapSense_2_CALIBRATION_FREQ_KHZ       (3000u)
#define CapSense_2_CALIBRATION_MD             (2u)

#define CapSense_2_MAX_RESOLUTION         (65535u)
#define CapSense_2_CALIBRATION_RESOLUTION (0x0FFF0000u)

#define CapSense_2_PRS_CORRECTION_DIVIDER (4u)
#define CapSense_2_SENSITIVITY_DIVIDER    (10u)

#define CapSense_2_SENSITIVITY_MASK           (0x0Fu)
#define CapSense_2_FLEXIBLE_THRESHOLDS_EN     (0u)
#define CapSense_2_CAL_RAW_COUNT              (3482u)

#define CapSense_2_THRESHOLD_1                (220u)
#define CapSense_2_THRESHOLD_2                (237u)
#define CapSense_2_THRESHOLD_3                (245u)
#define CapSense_2_THRESHOLD_4                (250u)


#if (0u != CapSense_2_IS_M0S8PERI_BLOCK)
    #define CapSense_2_CALIBRATION_ASD        (CYDEV_BCLK__HFCLK__KHZ /\
                                                     CapSense_2_CALIBRATION_FREQ_KHZ)
#else
    #define CapSense_2_MIN_IMO_FREQ_KHZ       (6000u)
    #if(CYDEV_BCLK__HFCLK__KHZ < CapSense_2_MIN_IMO_FREQ_KHZ)
        #define CapSense_2_CALIBRATION_ASD            (1u)
    #else
        #define CapSense_2_CALIBRATION_ASD    (CYDEV_BCLK__HFCLK__KHZ / CapSense_2_CALIBRATION_MD /\
                                                     CapSense_2_CALIBRATION_FREQ_KHZ)
    #endif /* (CYDEV_BCLK__HFCLK__KHZ < CapSense_2_MIN_IMO_FREQ_KHZ) */
#endif /* (0u != CapSense_2_IS_M0S8PERI_BLOCK) */

#if (0u != CapSense_2_IS_M0S8PERI_BLOCK)
    /*  Dividers are not chained */
    #if(CapSense_2_PRS_OPTIONS != CapSense_2__PRS_NONE)
        #define CapSense_2_SENSETIVITY_FACTOR (1228u)
    #else
        #define CapSense_2_SENSETIVITY_FACTOR (2456u)
    #endif /* (CapSense_2_PRS_OPTIONS == CapSense_2__PRS_NONE) */
#else
    /*  Dividers are chained */
    #if(CapSense_2_PRS_OPTIONS != CapSense_2__PRS_NONE)
        #define CapSense_2_SENSETIVITY_FACTOR (1228u/CapSense_2_CALIBRATION_MD)
    #else
        #define CapSense_2_SENSETIVITY_FACTOR (2456u/CapSense_2_CALIBRATION_MD)
    #endif /* (CapSense_2_PRS_OPTIONS == CapSense_2__PRS_NONE) */
#endif /* (0u != CapSense_2_IS_M0S8PERI_BLOCK) */


/***************************************
*        Function Prototypes
***************************************/
void CapSense_2_AutoTune(void);
void CapSense_2_UpdateThresholds(uint32 sensor);
void CapSense_2_SetSensitivity(uint32 sensor, uint32 value);
void CapSense_2_SetAnalogSwitchesSrcDirect(void);
uint16 CapSense_2_GetNoiseEnvelope(uint32 sensor);
uint8 CapSense_2_GetSensitivityCoefficient(uint32 sensor);
uint16 CapSense_2_GetNormalizedDiffCountData(uint32 sensor);


/***************************************
*     Vars with External Linkage
***************************************/

/*  Real Charge Divider values */
#if (0u != CapSense_2_IS_M0S8PERI_BLOCK)
    /*  Dividers are not chained */
    #if (CYDEV_BCLK__HFCLK__MHZ >= 12u)
        extern const uint8 prescalerTable[CapSense_2_PRESCALERS_TBL_SIZE];
    #elif (CYDEV_BCLK__HFCLK__MHZ >= 6u)
        extern const uint8 prescalerTable[CapSense_2_PRESCALERS_TBL_SIZE];
    #else
        extern const uint8 prescalerTable[CapSense_2_PRESCALERS_TBL_SIZE];
    #endif /* (CYDEV_BCLK__HFCLK__MHZ > 12u) */
#else
    /*  Dividers are chained */
    #if (CYDEV_BCLK__HFCLK__MHZ > 24u)
        extern const uint8 prescalerTable[CapSense_2_PRESCALERS_TBL_SIZE];
    #elif (CYDEV_BCLK__HFCLK__MHZ >12u)
        extern const uint8 prescalerTable[CapSense_2_PRESCALERS_TBL_SIZE];
    #else   /* (CYDEV_BCLK__HFCLK__MHZ > 12u) */
        extern const uint8 prescalerTable[CapSense_2_PRESCALERS_TBL_SIZE];
    #endif /* (CYDEV_BCLK__HFCLK__MHZ > 24u) */
#endif /* (0u != CapSense_2_IS_M0S8PERI_BLOCK) */


extern uint8 CapSense_2_noiseEnvelopeTbl[CapSense_2_TOTAL_SENSOR_COUNT];
extern uint8 CapSense_2_runningDifferenceTbl[CapSense_2_TOTAL_SENSOR_COUNT];
extern uint8 CapSense_2_signRegisterTbl[CapSense_2_TOTAL_SENSOR_COUNT];
extern uint16 CapSense_2_sampleMinTbl[CapSense_2_TOTAL_SENSOR_COUNT];
extern uint16 CapSense_2_sampleMaxTbl[CapSense_2_TOTAL_SENSOR_COUNT];
extern uint16 CapSense_2_previousSampleTbl[CapSense_2_TOTAL_SENSOR_COUNT];
extern uint8 CapSense_2_kValueTbl[CapSense_2_TOTAL_SENSOR_COUNT];


#endif  /* (CY_CAPSENSE_CSD_SMS_CapSense_2_H) */

/* [] END OF FILE */
