/*******************************************************************************
* File Name: LED_gruen_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "LED_gruen.h"

/* Check for removal by optimization */
#if !defined(LED_gruen_Sync_ctrl_reg__REMOVED)

static LED_gruen_BACKUP_STRUCT  LED_gruen_backup = {0u};

    
/*******************************************************************************
* Function Name: LED_gruen_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LED_gruen_SaveConfig(void) 
{
    LED_gruen_backup.controlState = LED_gruen_Control;
}


/*******************************************************************************
* Function Name: LED_gruen_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void LED_gruen_RestoreConfig(void) 
{
     LED_gruen_Control = LED_gruen_backup.controlState;
}


/*******************************************************************************
* Function Name: LED_gruen_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LED_gruen_Sleep(void) 
{
    LED_gruen_SaveConfig();
}


/*******************************************************************************
* Function Name: LED_gruen_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LED_gruen_Wakeup(void)  
{
    LED_gruen_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
