/***************************************************************************//**
* \file Matrix_RegisterMap.h
* \version 3.0
*
* \brief
*   This file provides the definitions for the component data structure register.
*
* \see CapSense P4 v3.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_CAPSENSE_Matrix_REGISTER_MAP_H)
#define CY_CAPSENSE_Matrix_REGISTER_MAP_H

#include <cytypes.h>
#include "Matrix_Configuration.h"
#include "Matrix_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define Matrix_CONFIG_ID_VALUE                              (Matrix_dsRam.configId)
#define Matrix_CONFIG_ID_OFFSET                             (0u)
#define Matrix_CONFIG_ID_SIZE                               (2u)
#define Matrix_CONFIG_ID_PARAM_ID                           (0x87000000u)

#define Matrix_DEVICE_ID_VALUE                              (Matrix_dsRam.deviceId)
#define Matrix_DEVICE_ID_OFFSET                             (2u)
#define Matrix_DEVICE_ID_SIZE                               (2u)
#define Matrix_DEVICE_ID_PARAM_ID                           (0x8B000002u)

#define Matrix_TUNER_CMD_VALUE                              (Matrix_dsRam.tunerCmd)
#define Matrix_TUNER_CMD_OFFSET                             (4u)
#define Matrix_TUNER_CMD_SIZE                               (2u)
#define Matrix_TUNER_CMD_PARAM_ID                           (0xAD000004u)

#define Matrix_SCAN_COUNTER_VALUE                           (Matrix_dsRam.scanCounter)
#define Matrix_SCAN_COUNTER_OFFSET                          (6u)
#define Matrix_SCAN_COUNTER_SIZE                            (2u)
#define Matrix_SCAN_COUNTER_PARAM_ID                        (0x8A000006u)

#define Matrix_STATUS_VALUE                                 (Matrix_dsRam.status)
#define Matrix_STATUS_OFFSET                                (8u)
#define Matrix_STATUS_SIZE                                  (4u)
#define Matrix_STATUS_PARAM_ID                              (0xCA000008u)

#define Matrix_WDGT_ENABLE0_VALUE                           (Matrix_dsRam.wdgtEnable[0u])
#define Matrix_WDGT_ENABLE0_OFFSET                          (12u)
#define Matrix_WDGT_ENABLE0_SIZE                            (4u)
#define Matrix_WDGT_ENABLE0_PARAM_ID                        (0xE000000Cu)

#define Matrix_WDGT_STATUS0_VALUE                           (Matrix_dsRam.wdgtStatus[0u])
#define Matrix_WDGT_STATUS0_OFFSET                          (16u)
#define Matrix_WDGT_STATUS0_SIZE                            (4u)
#define Matrix_WDGT_STATUS0_PARAM_ID                        (0xCD000010u)

#define Matrix_SNS_STATUS0_VALUE                            (Matrix_dsRam.snsStatus[0u])
#define Matrix_SNS_STATUS0_OFFSET                           (20u)
#define Matrix_SNS_STATUS0_SIZE                             (1u)
#define Matrix_SNS_STATUS0_PARAM_ID                         (0x4B000014u)

#define Matrix_CSD0_CONFIG_VALUE                            (Matrix_dsRam.csd0Config)
#define Matrix_CSD0_CONFIG_OFFSET                           (22u)
#define Matrix_CSD0_CONFIG_SIZE                             (2u)
#define Matrix_CSD0_CONFIG_PARAM_ID                         (0xA4000016u)

#define Matrix_MOD_CSD_CLK_VALUE                            (Matrix_dsRam.modCsdClk)
#define Matrix_MOD_CSD_CLK_OFFSET                           (24u)
#define Matrix_MOD_CSD_CLK_SIZE                             (1u)
#define Matrix_MOD_CSD_CLK_PARAM_ID                         (0x63000018u)

#define Matrix_MATRIXBUTTONS0_RESOLUTION_VALUE              (Matrix_dsRam.wdgtList.matrixbuttons0.resolution)
#define Matrix_MATRIXBUTTONS0_RESOLUTION_OFFSET             (26u)
#define Matrix_MATRIXBUTTONS0_RESOLUTION_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_RESOLUTION_PARAM_ID           (0x8180001Au)

#define Matrix_MATRIXBUTTONS0_FINGER_TH_VALUE               (Matrix_dsRam.wdgtList.matrixbuttons0.fingerTh)
#define Matrix_MATRIXBUTTONS0_FINGER_TH_OFFSET              (28u)
#define Matrix_MATRIXBUTTONS0_FINGER_TH_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_FINGER_TH_PARAM_ID            (0x8C80001Cu)

#define Matrix_MATRIXBUTTONS0_NOISE_TH_VALUE                (Matrix_dsRam.wdgtList.matrixbuttons0.noiseTh)
#define Matrix_MATRIXBUTTONS0_NOISE_TH_OFFSET               (30u)
#define Matrix_MATRIXBUTTONS0_NOISE_TH_SIZE                 (1u)
#define Matrix_MATRIXBUTTONS0_NOISE_TH_PARAM_ID             (0x4880001Eu)

#define Matrix_MATRIXBUTTONS0_NNOISE_TH_VALUE               (Matrix_dsRam.wdgtList.matrixbuttons0.nNoiseTh)
#define Matrix_MATRIXBUTTONS0_NNOISE_TH_OFFSET              (31u)
#define Matrix_MATRIXBUTTONS0_NNOISE_TH_SIZE                (1u)
#define Matrix_MATRIXBUTTONS0_NNOISE_TH_PARAM_ID            (0x4E80001Fu)

#define Matrix_MATRIXBUTTONS0_HYSTERESIS_VALUE              (Matrix_dsRam.wdgtList.matrixbuttons0.hysteresis)
#define Matrix_MATRIXBUTTONS0_HYSTERESIS_OFFSET             (32u)
#define Matrix_MATRIXBUTTONS0_HYSTERESIS_SIZE               (1u)
#define Matrix_MATRIXBUTTONS0_HYSTERESIS_PARAM_ID           (0x48800020u)

#define Matrix_MATRIXBUTTONS0_ON_DEBOUNCE_VALUE             (Matrix_dsRam.wdgtList.matrixbuttons0.onDebounce)
#define Matrix_MATRIXBUTTONS0_ON_DEBOUNCE_OFFSET            (33u)
#define Matrix_MATRIXBUTTONS0_ON_DEBOUNCE_SIZE              (1u)
#define Matrix_MATRIXBUTTONS0_ON_DEBOUNCE_PARAM_ID          (0x4E800021u)

#define Matrix_MATRIXBUTTONS0_LOW_BSLN_RST_VALUE            (Matrix_dsRam.wdgtList.matrixbuttons0.lowBslnRst)
#define Matrix_MATRIXBUTTONS0_LOW_BSLN_RST_OFFSET           (34u)
#define Matrix_MATRIXBUTTONS0_LOW_BSLN_RST_SIZE             (1u)
#define Matrix_MATRIXBUTTONS0_LOW_BSLN_RST_PARAM_ID         (0x44800022u)

#define Matrix_MATRIXBUTTONS0_BSLN_COEFF_VALUE              (Matrix_dsRam.wdgtList.matrixbuttons0.bslnCoeff)
#define Matrix_MATRIXBUTTONS0_BSLN_COEFF_OFFSET             (35u)
#define Matrix_MATRIXBUTTONS0_BSLN_COEFF_SIZE               (1u)
#define Matrix_MATRIXBUTTONS0_BSLN_COEFF_PARAM_ID           (0x69800023u)

#define Matrix_MATRIXBUTTONS0_IDAC_MOD0_VALUE               (Matrix_dsRam.wdgtList.matrixbuttons0.idacMod[0u])
#define Matrix_MATRIXBUTTONS0_IDAC_MOD0_OFFSET              (36u)
#define Matrix_MATRIXBUTTONS0_IDAC_MOD0_SIZE                (1u)
#define Matrix_MATRIXBUTTONS0_IDAC_MOD0_PARAM_ID            (0x49800024u)

#define Matrix_MATRIXBUTTONS0_ROW_IDAC_MOD0_VALUE           (Matrix_dsRam.wdgtList.matrixbuttons0.rowIdacMod[0u])
#define Matrix_MATRIXBUTTONS0_ROW_IDAC_MOD0_OFFSET          (37u)
#define Matrix_MATRIXBUTTONS0_ROW_IDAC_MOD0_SIZE            (1u)
#define Matrix_MATRIXBUTTONS0_ROW_IDAC_MOD0_PARAM_ID        (0x4F800025u)

#define Matrix_MATRIXBUTTONS0_SNS_CLK_VALUE                 (Matrix_dsRam.wdgtList.matrixbuttons0.snsClk)
#define Matrix_MATRIXBUTTONS0_SNS_CLK_OFFSET                (38u)
#define Matrix_MATRIXBUTTONS0_SNS_CLK_SIZE                  (1u)
#define Matrix_MATRIXBUTTONS0_SNS_CLK_PARAM_ID              (0x45800026u)

#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_VALUE             (Matrix_dsRam.wdgtList.matrixbuttons0.rowSnsClk)
#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_OFFSET            (39u)
#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_SIZE              (1u)
#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_PARAM_ID          (0x43800027u)

#define Matrix_MATRIXBUTTONS0_SNS_CLK_SOURCE_VALUE          (Matrix_dsRam.wdgtList.matrixbuttons0.snsClkSource)
#define Matrix_MATRIXBUTTONS0_SNS_CLK_SOURCE_OFFSET         (40u)
#define Matrix_MATRIXBUTTONS0_SNS_CLK_SOURCE_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_SNS_CLK_SOURCE_PARAM_ID       (0x4A800028u)

#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_SOURCE_VALUE      (Matrix_dsRam.wdgtList.matrixbuttons0.rowSnsClkSource)
#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_SOURCE_OFFSET     (41u)
#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_SOURCE_SIZE       (1u)
#define Matrix_MATRIXBUTTONS0_ROW_SNS_CLK_SOURCE_PARAM_ID   (0x4C800029u)

#define Matrix_MATRIXBUTTONS0_FINGER_CAP_VALUE              (Matrix_dsRam.wdgtList.matrixbuttons0.fingerCap)
#define Matrix_MATRIXBUTTONS0_FINGER_CAP_OFFSET             (42u)
#define Matrix_MATRIXBUTTONS0_FINGER_CAP_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_FINGER_CAP_PARAM_ID           (0xA580002Au)

#define Matrix_MATRIXBUTTONS0_SIGPFC_VALUE                  (Matrix_dsRam.wdgtList.matrixbuttons0.sigPFC)
#define Matrix_MATRIXBUTTONS0_SIGPFC_OFFSET                 (44u)
#define Matrix_MATRIXBUTTONS0_SIGPFC_SIZE                   (2u)
#define Matrix_MATRIXBUTTONS0_SIGPFC_PARAM_ID               (0xA880002Cu)

#define Matrix_MATRIXBUTTONS0_POS_COL_VALUE                 (Matrix_dsRam.wdgtList.matrixbuttons0.posCol)
#define Matrix_MATRIXBUTTONS0_POS_COL_OFFSET                (46u)
#define Matrix_MATRIXBUTTONS0_POS_COL_SIZE                  (1u)
#define Matrix_MATRIXBUTTONS0_POS_COL_PARAM_ID              (0x4780002Eu)

#define Matrix_MATRIXBUTTONS0_POS_ROW_VALUE                 (Matrix_dsRam.wdgtList.matrixbuttons0.posRow)
#define Matrix_MATRIXBUTTONS0_POS_ROW_OFFSET                (47u)
#define Matrix_MATRIXBUTTONS0_POS_ROW_SIZE                  (1u)
#define Matrix_MATRIXBUTTONS0_POS_ROW_PARAM_ID              (0x4180002Fu)

#define Matrix_MATRIXBUTTONS0_POS_SNS_ID_VALUE              (Matrix_dsRam.wdgtList.matrixbuttons0.posSnsId)
#define Matrix_MATRIXBUTTONS0_POS_SNS_ID_OFFSET             (48u)
#define Matrix_MATRIXBUTTONS0_POS_SNS_ID_SIZE               (1u)
#define Matrix_MATRIXBUTTONS0_POS_SNS_ID_PARAM_ID           (0x4D800030u)

#define Matrix_MATRIXBUTTONS0_COL0_RAW0_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[0u].raw[0u])
#define Matrix_MATRIXBUTTONS0_COL0_RAW0_OFFSET              (50u)
#define Matrix_MATRIXBUTTONS0_COL0_RAW0_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_COL0_RAW0_PARAM_ID            (0x84000032u)

#define Matrix_MATRIXBUTTONS0_COL0_BSLN0_VALUE              (Matrix_dsRam.snsList.matrixbuttons0[0u].bsln[0u])
#define Matrix_MATRIXBUTTONS0_COL0_BSLN0_OFFSET             (52u)
#define Matrix_MATRIXBUTTONS0_COL0_BSLN0_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_COL0_BSLN0_PARAM_ID           (0x89000034u)

#define Matrix_MATRIXBUTTONS0_COL0_BSLN_EXT0_VALUE          (Matrix_dsRam.snsList.matrixbuttons0[0u].bslnExt[0u])
#define Matrix_MATRIXBUTTONS0_COL0_BSLN_EXT0_OFFSET         (54u)
#define Matrix_MATRIXBUTTONS0_COL0_BSLN_EXT0_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_COL0_BSLN_EXT0_PARAM_ID       (0x4D000036u)

#define Matrix_MATRIXBUTTONS0_COL0_IDAC_COMP0_VALUE         (Matrix_dsRam.snsList.matrixbuttons0[0u].idacComp[0u])
#define Matrix_MATRIXBUTTONS0_COL0_IDAC_COMP0_OFFSET        (55u)
#define Matrix_MATRIXBUTTONS0_COL0_IDAC_COMP0_SIZE          (1u)
#define Matrix_MATRIXBUTTONS0_COL0_IDAC_COMP0_PARAM_ID      (0x4B000037u)

#define Matrix_MATRIXBUTTONS0_COL0_DIFF_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[0u].diff)
#define Matrix_MATRIXBUTTONS0_COL0_DIFF_OFFSET              (56u)
#define Matrix_MATRIXBUTTONS0_COL0_DIFF_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_COL0_DIFF_PARAM_ID            (0x8A000038u)

#define Matrix_MATRIXBUTTONS0_COL0_NEG_BSLN_RST_CNT0_VALUE  (Matrix_dsRam.snsList.matrixbuttons0[0u].negBslnRstCnt[0u])
#define Matrix_MATRIXBUTTONS0_COL0_NEG_BSLN_RST_CNT0_OFFSET (58u)
#define Matrix_MATRIXBUTTONS0_COL0_NEG_BSLN_RST_CNT0_SIZE   (1u)
#define Matrix_MATRIXBUTTONS0_COL0_NEG_BSLN_RST_CNT0_PARAM_ID (0x4E00003Au)

#define Matrix_MATRIXBUTTONS0_COL1_RAW0_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[1u].raw[0u])
#define Matrix_MATRIXBUTTONS0_COL1_RAW0_OFFSET              (60u)
#define Matrix_MATRIXBUTTONS0_COL1_RAW0_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_COL1_RAW0_PARAM_ID            (0x8B00003Cu)

#define Matrix_MATRIXBUTTONS0_COL1_BSLN0_VALUE              (Matrix_dsRam.snsList.matrixbuttons0[1u].bsln[0u])
#define Matrix_MATRIXBUTTONS0_COL1_BSLN0_OFFSET             (62u)
#define Matrix_MATRIXBUTTONS0_COL1_BSLN0_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_COL1_BSLN0_PARAM_ID           (0x8700003Eu)

#define Matrix_MATRIXBUTTONS0_COL1_BSLN_EXT0_VALUE          (Matrix_dsRam.snsList.matrixbuttons0[1u].bslnExt[0u])
#define Matrix_MATRIXBUTTONS0_COL1_BSLN_EXT0_OFFSET         (64u)
#define Matrix_MATRIXBUTTONS0_COL1_BSLN_EXT0_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_COL1_BSLN_EXT0_PARAM_ID       (0x42000040u)

#define Matrix_MATRIXBUTTONS0_COL1_IDAC_COMP0_VALUE         (Matrix_dsRam.snsList.matrixbuttons0[1u].idacComp[0u])
#define Matrix_MATRIXBUTTONS0_COL1_IDAC_COMP0_OFFSET        (65u)
#define Matrix_MATRIXBUTTONS0_COL1_IDAC_COMP0_SIZE          (1u)
#define Matrix_MATRIXBUTTONS0_COL1_IDAC_COMP0_PARAM_ID      (0x44000041u)

#define Matrix_MATRIXBUTTONS0_COL1_DIFF_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[1u].diff)
#define Matrix_MATRIXBUTTONS0_COL1_DIFF_OFFSET              (66u)
#define Matrix_MATRIXBUTTONS0_COL1_DIFF_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_COL1_DIFF_PARAM_ID            (0x86000042u)

#define Matrix_MATRIXBUTTONS0_COL1_NEG_BSLN_RST_CNT0_VALUE  (Matrix_dsRam.snsList.matrixbuttons0[1u].negBslnRstCnt[0u])
#define Matrix_MATRIXBUTTONS0_COL1_NEG_BSLN_RST_CNT0_OFFSET (68u)
#define Matrix_MATRIXBUTTONS0_COL1_NEG_BSLN_RST_CNT0_SIZE   (1u)
#define Matrix_MATRIXBUTTONS0_COL1_NEG_BSLN_RST_CNT0_PARAM_ID (0x43000044u)

#define Matrix_MATRIXBUTTONS0_COL2_RAW0_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[2u].raw[0u])
#define Matrix_MATRIXBUTTONS0_COL2_RAW0_OFFSET              (70u)
#define Matrix_MATRIXBUTTONS0_COL2_RAW0_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_COL2_RAW0_PARAM_ID            (0x87000046u)

#define Matrix_MATRIXBUTTONS0_COL2_BSLN0_VALUE              (Matrix_dsRam.snsList.matrixbuttons0[2u].bsln[0u])
#define Matrix_MATRIXBUTTONS0_COL2_BSLN0_OFFSET             (72u)
#define Matrix_MATRIXBUTTONS0_COL2_BSLN0_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_COL2_BSLN0_PARAM_ID           (0x88000048u)

#define Matrix_MATRIXBUTTONS0_COL2_BSLN_EXT0_VALUE          (Matrix_dsRam.snsList.matrixbuttons0[2u].bslnExt[0u])
#define Matrix_MATRIXBUTTONS0_COL2_BSLN_EXT0_OFFSET         (74u)
#define Matrix_MATRIXBUTTONS0_COL2_BSLN_EXT0_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_COL2_BSLN_EXT0_PARAM_ID       (0x4C00004Au)

#define Matrix_MATRIXBUTTONS0_COL2_IDAC_COMP0_VALUE         (Matrix_dsRam.snsList.matrixbuttons0[2u].idacComp[0u])
#define Matrix_MATRIXBUTTONS0_COL2_IDAC_COMP0_OFFSET        (75u)
#define Matrix_MATRIXBUTTONS0_COL2_IDAC_COMP0_SIZE          (1u)
#define Matrix_MATRIXBUTTONS0_COL2_IDAC_COMP0_PARAM_ID      (0x4A00004Bu)

#define Matrix_MATRIXBUTTONS0_COL2_DIFF_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[2u].diff)
#define Matrix_MATRIXBUTTONS0_COL2_DIFF_OFFSET              (76u)
#define Matrix_MATRIXBUTTONS0_COL2_DIFF_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_COL2_DIFF_PARAM_ID            (0x8900004Cu)

#define Matrix_MATRIXBUTTONS0_COL2_NEG_BSLN_RST_CNT0_VALUE  (Matrix_dsRam.snsList.matrixbuttons0[2u].negBslnRstCnt[0u])
#define Matrix_MATRIXBUTTONS0_COL2_NEG_BSLN_RST_CNT0_OFFSET (78u)
#define Matrix_MATRIXBUTTONS0_COL2_NEG_BSLN_RST_CNT0_SIZE   (1u)
#define Matrix_MATRIXBUTTONS0_COL2_NEG_BSLN_RST_CNT0_PARAM_ID (0x4D00004Eu)

#define Matrix_MATRIXBUTTONS0_ROW0_RAW0_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[3u].raw[0u])
#define Matrix_MATRIXBUTTONS0_ROW0_RAW0_OFFSET              (80u)
#define Matrix_MATRIXBUTTONS0_ROW0_RAW0_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW0_RAW0_PARAM_ID            (0x8F000050u)

#define Matrix_MATRIXBUTTONS0_ROW0_BSLN0_VALUE              (Matrix_dsRam.snsList.matrixbuttons0[3u].bsln[0u])
#define Matrix_MATRIXBUTTONS0_ROW0_BSLN0_OFFSET             (82u)
#define Matrix_MATRIXBUTTONS0_ROW0_BSLN0_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_ROW0_BSLN0_PARAM_ID           (0x83000052u)

#define Matrix_MATRIXBUTTONS0_ROW0_BSLN_EXT0_VALUE          (Matrix_dsRam.snsList.matrixbuttons0[3u].bslnExt[0u])
#define Matrix_MATRIXBUTTONS0_ROW0_BSLN_EXT0_OFFSET         (84u)
#define Matrix_MATRIXBUTTONS0_ROW0_BSLN_EXT0_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_ROW0_BSLN_EXT0_PARAM_ID       (0x46000054u)

#define Matrix_MATRIXBUTTONS0_ROW0_IDAC_COMP0_VALUE         (Matrix_dsRam.snsList.matrixbuttons0[3u].idacComp[0u])
#define Matrix_MATRIXBUTTONS0_ROW0_IDAC_COMP0_OFFSET        (85u)
#define Matrix_MATRIXBUTTONS0_ROW0_IDAC_COMP0_SIZE          (1u)
#define Matrix_MATRIXBUTTONS0_ROW0_IDAC_COMP0_PARAM_ID      (0x40000055u)

#define Matrix_MATRIXBUTTONS0_ROW0_DIFF_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[3u].diff)
#define Matrix_MATRIXBUTTONS0_ROW0_DIFF_OFFSET              (86u)
#define Matrix_MATRIXBUTTONS0_ROW0_DIFF_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW0_DIFF_PARAM_ID            (0x82000056u)

#define Matrix_MATRIXBUTTONS0_ROW0_NEG_BSLN_RST_CNT0_VALUE  (Matrix_dsRam.snsList.matrixbuttons0[3u].negBslnRstCnt[0u])
#define Matrix_MATRIXBUTTONS0_ROW0_NEG_BSLN_RST_CNT0_OFFSET (88u)
#define Matrix_MATRIXBUTTONS0_ROW0_NEG_BSLN_RST_CNT0_SIZE   (1u)
#define Matrix_MATRIXBUTTONS0_ROW0_NEG_BSLN_RST_CNT0_PARAM_ID (0x45000058u)

#define Matrix_MATRIXBUTTONS0_ROW1_RAW0_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[4u].raw[0u])
#define Matrix_MATRIXBUTTONS0_ROW1_RAW0_OFFSET              (90u)
#define Matrix_MATRIXBUTTONS0_ROW1_RAW0_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW1_RAW0_PARAM_ID            (0x8100005Au)

#define Matrix_MATRIXBUTTONS0_ROW1_BSLN0_VALUE              (Matrix_dsRam.snsList.matrixbuttons0[4u].bsln[0u])
#define Matrix_MATRIXBUTTONS0_ROW1_BSLN0_OFFSET             (92u)
#define Matrix_MATRIXBUTTONS0_ROW1_BSLN0_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_ROW1_BSLN0_PARAM_ID           (0x8C00005Cu)

#define Matrix_MATRIXBUTTONS0_ROW1_BSLN_EXT0_VALUE          (Matrix_dsRam.snsList.matrixbuttons0[4u].bslnExt[0u])
#define Matrix_MATRIXBUTTONS0_ROW1_BSLN_EXT0_OFFSET         (94u)
#define Matrix_MATRIXBUTTONS0_ROW1_BSLN_EXT0_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_ROW1_BSLN_EXT0_PARAM_ID       (0x4800005Eu)

#define Matrix_MATRIXBUTTONS0_ROW1_IDAC_COMP0_VALUE         (Matrix_dsRam.snsList.matrixbuttons0[4u].idacComp[0u])
#define Matrix_MATRIXBUTTONS0_ROW1_IDAC_COMP0_OFFSET        (95u)
#define Matrix_MATRIXBUTTONS0_ROW1_IDAC_COMP0_SIZE          (1u)
#define Matrix_MATRIXBUTTONS0_ROW1_IDAC_COMP0_PARAM_ID      (0x4E00005Fu)

#define Matrix_MATRIXBUTTONS0_ROW1_DIFF_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[4u].diff)
#define Matrix_MATRIXBUTTONS0_ROW1_DIFF_OFFSET              (96u)
#define Matrix_MATRIXBUTTONS0_ROW1_DIFF_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW1_DIFF_PARAM_ID            (0x80000060u)

#define Matrix_MATRIXBUTTONS0_ROW1_NEG_BSLN_RST_CNT0_VALUE  (Matrix_dsRam.snsList.matrixbuttons0[4u].negBslnRstCnt[0u])
#define Matrix_MATRIXBUTTONS0_ROW1_NEG_BSLN_RST_CNT0_OFFSET (98u)
#define Matrix_MATRIXBUTTONS0_ROW1_NEG_BSLN_RST_CNT0_SIZE   (1u)
#define Matrix_MATRIXBUTTONS0_ROW1_NEG_BSLN_RST_CNT0_PARAM_ID (0x44000062u)

#define Matrix_MATRIXBUTTONS0_ROW2_RAW0_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[5u].raw[0u])
#define Matrix_MATRIXBUTTONS0_ROW2_RAW0_OFFSET              (100u)
#define Matrix_MATRIXBUTTONS0_ROW2_RAW0_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW2_RAW0_PARAM_ID            (0x81000064u)

#define Matrix_MATRIXBUTTONS0_ROW2_BSLN0_VALUE              (Matrix_dsRam.snsList.matrixbuttons0[5u].bsln[0u])
#define Matrix_MATRIXBUTTONS0_ROW2_BSLN0_OFFSET             (102u)
#define Matrix_MATRIXBUTTONS0_ROW2_BSLN0_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_ROW2_BSLN0_PARAM_ID           (0x8D000066u)

#define Matrix_MATRIXBUTTONS0_ROW2_BSLN_EXT0_VALUE          (Matrix_dsRam.snsList.matrixbuttons0[5u].bslnExt[0u])
#define Matrix_MATRIXBUTTONS0_ROW2_BSLN_EXT0_OFFSET         (104u)
#define Matrix_MATRIXBUTTONS0_ROW2_BSLN_EXT0_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_ROW2_BSLN_EXT0_PARAM_ID       (0x4A000068u)

#define Matrix_MATRIXBUTTONS0_ROW2_IDAC_COMP0_VALUE         (Matrix_dsRam.snsList.matrixbuttons0[5u].idacComp[0u])
#define Matrix_MATRIXBUTTONS0_ROW2_IDAC_COMP0_OFFSET        (105u)
#define Matrix_MATRIXBUTTONS0_ROW2_IDAC_COMP0_SIZE          (1u)
#define Matrix_MATRIXBUTTONS0_ROW2_IDAC_COMP0_PARAM_ID      (0x4C000069u)

#define Matrix_MATRIXBUTTONS0_ROW2_DIFF_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[5u].diff)
#define Matrix_MATRIXBUTTONS0_ROW2_DIFF_OFFSET              (106u)
#define Matrix_MATRIXBUTTONS0_ROW2_DIFF_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW2_DIFF_PARAM_ID            (0x8E00006Au)

#define Matrix_MATRIXBUTTONS0_ROW2_NEG_BSLN_RST_CNT0_VALUE  (Matrix_dsRam.snsList.matrixbuttons0[5u].negBslnRstCnt[0u])
#define Matrix_MATRIXBUTTONS0_ROW2_NEG_BSLN_RST_CNT0_OFFSET (108u)
#define Matrix_MATRIXBUTTONS0_ROW2_NEG_BSLN_RST_CNT0_SIZE   (1u)
#define Matrix_MATRIXBUTTONS0_ROW2_NEG_BSLN_RST_CNT0_PARAM_ID (0x4B00006Cu)

#define Matrix_MATRIXBUTTONS0_ROW3_RAW0_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[6u].raw[0u])
#define Matrix_MATRIXBUTTONS0_ROW3_RAW0_OFFSET              (110u)
#define Matrix_MATRIXBUTTONS0_ROW3_RAW0_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW3_RAW0_PARAM_ID            (0x8F00006Eu)

#define Matrix_MATRIXBUTTONS0_ROW3_BSLN0_VALUE              (Matrix_dsRam.snsList.matrixbuttons0[6u].bsln[0u])
#define Matrix_MATRIXBUTTONS0_ROW3_BSLN0_OFFSET             (112u)
#define Matrix_MATRIXBUTTONS0_ROW3_BSLN0_SIZE               (2u)
#define Matrix_MATRIXBUTTONS0_ROW3_BSLN0_PARAM_ID           (0x85000070u)

#define Matrix_MATRIXBUTTONS0_ROW3_BSLN_EXT0_VALUE          (Matrix_dsRam.snsList.matrixbuttons0[6u].bslnExt[0u])
#define Matrix_MATRIXBUTTONS0_ROW3_BSLN_EXT0_OFFSET         (114u)
#define Matrix_MATRIXBUTTONS0_ROW3_BSLN_EXT0_SIZE           (1u)
#define Matrix_MATRIXBUTTONS0_ROW3_BSLN_EXT0_PARAM_ID       (0x41000072u)

#define Matrix_MATRIXBUTTONS0_ROW3_IDAC_COMP0_VALUE         (Matrix_dsRam.snsList.matrixbuttons0[6u].idacComp[0u])
#define Matrix_MATRIXBUTTONS0_ROW3_IDAC_COMP0_OFFSET        (115u)
#define Matrix_MATRIXBUTTONS0_ROW3_IDAC_COMP0_SIZE          (1u)
#define Matrix_MATRIXBUTTONS0_ROW3_IDAC_COMP0_PARAM_ID      (0x47000073u)

#define Matrix_MATRIXBUTTONS0_ROW3_DIFF_VALUE               (Matrix_dsRam.snsList.matrixbuttons0[6u].diff)
#define Matrix_MATRIXBUTTONS0_ROW3_DIFF_OFFSET              (116u)
#define Matrix_MATRIXBUTTONS0_ROW3_DIFF_SIZE                (2u)
#define Matrix_MATRIXBUTTONS0_ROW3_DIFF_PARAM_ID            (0x84000074u)

#define Matrix_MATRIXBUTTONS0_ROW3_NEG_BSLN_RST_CNT0_VALUE  (Matrix_dsRam.snsList.matrixbuttons0[6u].negBslnRstCnt[0u])
#define Matrix_MATRIXBUTTONS0_ROW3_NEG_BSLN_RST_CNT0_OFFSET (118u)
#define Matrix_MATRIXBUTTONS0_ROW3_NEG_BSLN_RST_CNT0_SIZE   (1u)
#define Matrix_MATRIXBUTTONS0_ROW3_NEG_BSLN_RST_CNT0_PARAM_ID (0x40000076u)

#define Matrix_SNR_TEST_WIDGET_ID_VALUE                     (Matrix_dsRam.snrTestWidgetId)
#define Matrix_SNR_TEST_WIDGET_ID_OFFSET                    (120u)
#define Matrix_SNR_TEST_WIDGET_ID_SIZE                      (1u)
#define Matrix_SNR_TEST_WIDGET_ID_PARAM_ID                  (0x64000078u)

#define Matrix_SNR_TEST_SENSOR_ID_VALUE                     (Matrix_dsRam.snrTestSensorId)
#define Matrix_SNR_TEST_SENSOR_ID_OFFSET                    (121u)
#define Matrix_SNR_TEST_SENSOR_ID_SIZE                      (1u)
#define Matrix_SNR_TEST_SENSOR_ID_PARAM_ID                  (0x62000079u)

#define Matrix_SNR_TEST_SCAN_COUNTER_VALUE                  (Matrix_dsRam.snrTestScanCounter)
#define Matrix_SNR_TEST_SCAN_COUNTER_OFFSET                 (122u)
#define Matrix_SNR_TEST_SCAN_COUNTER_SIZE                   (2u)
#define Matrix_SNR_TEST_SCAN_COUNTER_PARAM_ID               (0x8B00007Au)

#define Matrix_SNR_TEST_RAW_COUNT0_VALUE                    (Matrix_dsRam.snrTestRawCount[0u])
#define Matrix_SNR_TEST_RAW_COUNT0_OFFSET                   (124u)
#define Matrix_SNR_TEST_RAW_COUNT0_SIZE                     (2u)
#define Matrix_SNR_TEST_RAW_COUNT0_PARAM_ID                 (0x8600007Cu)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define Matrix_MATRIXBUTTONS0_PTR2SNS_FLASH_VALUE           (Matrix_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define Matrix_MATRIXBUTTONS0_PTR2SNS_FLASH_OFFSET          (0u)
#define Matrix_MATRIXBUTTONS0_PTR2SNS_FLASH_SIZE            (4u)
#define Matrix_MATRIXBUTTONS0_PTR2SNS_FLASH_PARAM_ID        (0xD1000000u)

#define Matrix_MATRIXBUTTONS0_PTR2WD_RAM_VALUE              (Matrix_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define Matrix_MATRIXBUTTONS0_PTR2WD_RAM_OFFSET             (4u)
#define Matrix_MATRIXBUTTONS0_PTR2WD_RAM_SIZE               (4u)
#define Matrix_MATRIXBUTTONS0_PTR2WD_RAM_PARAM_ID           (0xD0000004u)

#define Matrix_MATRIXBUTTONS0_PTR2SNS_RAM_VALUE             (Matrix_dsFlash.wdgtArray[0].ptr2SnsRam)
#define Matrix_MATRIXBUTTONS0_PTR2SNS_RAM_OFFSET            (8u)
#define Matrix_MATRIXBUTTONS0_PTR2SNS_RAM_SIZE              (4u)
#define Matrix_MATRIXBUTTONS0_PTR2SNS_RAM_PARAM_ID          (0xD3000008u)

#define Matrix_MATRIXBUTTONS0_PTR2FLTR_HISTORY_VALUE        (Matrix_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define Matrix_MATRIXBUTTONS0_PTR2FLTR_HISTORY_OFFSET       (12u)
#define Matrix_MATRIXBUTTONS0_PTR2FLTR_HISTORY_SIZE         (4u)
#define Matrix_MATRIXBUTTONS0_PTR2FLTR_HISTORY_PARAM_ID     (0xD200000Cu)

#define Matrix_MATRIXBUTTONS0_PTR2DEBOUNCE_VALUE            (Matrix_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define Matrix_MATRIXBUTTONS0_PTR2DEBOUNCE_OFFSET           (16u)
#define Matrix_MATRIXBUTTONS0_PTR2DEBOUNCE_SIZE             (4u)
#define Matrix_MATRIXBUTTONS0_PTR2DEBOUNCE_PARAM_ID         (0xD4000010u)

#define Matrix_MATRIXBUTTONS0_STATIC_CONFIG_VALUE           (Matrix_dsFlash.wdgtArray[0].staticConfig)
#define Matrix_MATRIXBUTTONS0_STATIC_CONFIG_OFFSET          (20u)
#define Matrix_MATRIXBUTTONS0_STATIC_CONFIG_SIZE            (2u)
#define Matrix_MATRIXBUTTONS0_STATIC_CONFIG_PARAM_ID        (0x9A000014u)

#define Matrix_MATRIXBUTTONS0_TOTAL_NUM_SNS_VALUE           (Matrix_dsFlash.wdgtArray[0].totalNumSns)
#define Matrix_MATRIXBUTTONS0_TOTAL_NUM_SNS_OFFSET          (22u)
#define Matrix_MATRIXBUTTONS0_TOTAL_NUM_SNS_SIZE            (2u)
#define Matrix_MATRIXBUTTONS0_TOTAL_NUM_SNS_PARAM_ID        (0x96000016u)

#define Matrix_MATRIXBUTTONS0_TYPE_VALUE                    (Matrix_dsFlash.wdgtArray[0].wdgtType)
#define Matrix_MATRIXBUTTONS0_TYPE_OFFSET                   (24u)
#define Matrix_MATRIXBUTTONS0_TYPE_SIZE                     (1u)
#define Matrix_MATRIXBUTTONS0_TYPE_PARAM_ID                 (0x51000018u)

#define Matrix_MATRIXBUTTONS0_NUM_COLS_VALUE                (Matrix_dsFlash.wdgtArray[0].numCols)
#define Matrix_MATRIXBUTTONS0_NUM_COLS_OFFSET               (25u)
#define Matrix_MATRIXBUTTONS0_NUM_COLS_SIZE                 (1u)
#define Matrix_MATRIXBUTTONS0_NUM_COLS_PARAM_ID             (0x57000019u)

#define Matrix_MATRIXBUTTONS0_NUM_ROWS_VALUE                (Matrix_dsFlash.wdgtArray[0].numRows)
#define Matrix_MATRIXBUTTONS0_NUM_ROWS_OFFSET               (26u)
#define Matrix_MATRIXBUTTONS0_NUM_ROWS_SIZE                 (1u)
#define Matrix_MATRIXBUTTONS0_NUM_ROWS_PARAM_ID             (0x5D00001Au)

#define Matrix_MATRIXBUTTONS0_PTR2NOISE_ENVLP_VALUE         (Matrix_dsFlash.wdgtArray[0].ptr2NoiseEnvlp)
#define Matrix_MATRIXBUTTONS0_PTR2NOISE_ENVLP_OFFSET        (28u)
#define Matrix_MATRIXBUTTONS0_PTR2NOISE_ENVLP_SIZE          (4u)
#define Matrix_MATRIXBUTTONS0_PTR2NOISE_ENVLP_PARAM_ID      (0xD700001Cu)


#endif /* End CY_CAPSENSE_Matrix_REGISTER_MAP_H */

/* [] END OF FILE */
