/***************************************************************************//**
* \file Matrix_SensingCSD_LL.h
* \version 3.0
*
* \brief
*   This file provides the headers of APIs specific to CSD sensing implementation.
*
* \see CapSense P4 v3.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_CAPSENSE_Matrix_SENSINGCSD_LL_H)
#define CY_CAPSENSE_Matrix_SENSINGCSD_LL_H

#include <CyLib.h>
#include <cyfitter.h>
#include "cytypes.h"
#include "Matrix_Structure.h"
#include "Matrix_Configuration.h"

/***************************************
* Function Prototypes
**************************************/

/**
* \if SECTION_CAPSENSE_LOW_LEVEL
* \addtogroup group_capsense_low_level
* \{
*/

void Matrix_CSDSetupWidget(uint32 wdgtIndex);
void Matrix_CSDSetupWidgetExt(uint32 wdgtIndex, uint32 snsIndex);
void Matrix_CSDScan(void);
void Matrix_CSDScanExt(void);
#if ((Matrix_CSD_SS_DIS != Matrix_CSD_AUTOTUNE) || \
     (Matrix_ENABLE == Matrix_CSD_IDAC_AUTOCAL_EN))
    cystatus Matrix_CSDCalibrateWidget(uint32 wdgtIndex, uint32 target);
#endif /* ((Matrix_CSD_SS_DIS != Matrix_CSD_AUTOTUNE) || \
           (Matrix_ENABLE == Matrix_CSD_IDAC_AUTOCAL_EN))  */
void Matrix_CSDConnectSns(Matrix_FLASH_IO_STRUCT const *snsAddrPtr);
void Matrix_CSDDisconnectSns(Matrix_FLASH_IO_STRUCT const *snsAddrPtr);

/** \}
* \endif */

/*****************************************************
* Function Prototypes - internal Low Level functions
*****************************************************/
/**
* \if SECTION_CAPSENSE_INTERNAL
* \addtogroup group_capsense_internal
* \{
*/

void Matrix_SsCSDInitialize(void);
void Matrix_SsCSDStartSample(void);
void Matrix_SsCSDSetUpIdacs(Matrix_RAM_WD_BASE_STRUCT const *ptrWdgt);
void Matrix_SsCSDConfigClock(void);
void Matrix_SsCSDElectrodeCheck(void);
#if ((Matrix_ENABLE == Matrix_CSD_SHIELD_EN) && \
     (0u != Matrix_CSD_TOTAL_SHIELD_COUNT))
    void Matrix_SsCSDDisableShieldElectrodes(void);
#endif /* ((Matrix_ENABLE == Matrix_CSD_SHIELD_EN) && \
           (0u != Matrix_CSD_TOTAL_SHIELD_COUNT)) */
#if (Matrix_CLK_SOURCE_PRSAUTO == Matrix_CSD_SNS_CLK_SOURCE)
    uint8 Matrix_SsCSDCalcPrsSize(uint32 snsClkDivider, uint32 resolution);
#endif /* (Matrix_CLK_SOURCE_PRSAUTO == Matrix_CSD_SNS_CLK_SOURCE) */
#if (Matrix_ENABLE == Matrix_CSDV2)
    uint32 Matrix_SsCSDGetNumberOfConversions(uint32 snsClkDivider, uint32 resolution);
#endif /* (Matrix_ENABLE == Matrix_CSDV2) */
uint32 Matrix_SsCSDGetColSnsClkDivider(uint32 wdgtIndex);
#if (Matrix_ENABLE == (Matrix_CSD_MATRIX_WIDGET_EN | Matrix_CSD_TOUCHPAD_WIDGET_EN))
    uint32 Matrix_SsCSDGetRowSnsClkDivider(uint32 wdgtIndex);
#endif /* (Matrix_ENABLE == (Matrix_CSD_MATRIX_WIDGET_EN | Matrix_CSD_TOUCHPAD_WIDGET_EN)) */
void Matrix_SsCSDCalculateScanDuration(Matrix_RAM_WD_BASE_STRUCT const *ptrWdgt);
void Matrix_SsCSDConnectSensorExt(uint32 wdgtIndex, uint32 sensorIndex);
void Matrix_SsCSDDisconnectSnsExt(uint32 wdgtIndex, uint32 sensorIndex);

/** \}
* \endif */

/***************************************
* Global software variables
***************************************/
extern uint32 Matrix_configCsd;
/* Interrupt handler */
extern CY_ISR_PROTO(Matrix_CSDPostSingleScan);
extern CY_ISR_PROTO(Matrix_CSDPostMultiScan);
#if (Matrix_ENABLE == Matrix_CSD_GANGED_SNS_EN)
extern CY_ISR_PROTO(Matrix_CSDPostMultiScanGanged);
#endif /* (Matrix_ENABLE == Matrix_CSD_GANGED_SNS_EN) */
#if (Matrix_ENABLE == Matrix_CSD_NOISE_METRIC_EN)
    extern uint8 Matrix_badConversionsNum;
#endif /* (Matrix_ENABLE == Matrix_CSD_NOISE_METRIC_EN) */

#endif /* End CY_CAPSENSE_Matrix_SENSINGCSD_LL_H */


/* [] END OF FILE */
