/*******************************************************************************
* File Name: RTS1_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "RTS1.h"

/* Check for removal by optimization */
#if !defined(RTS1_Sync_ctrl_reg__REMOVED)

static RTS1_BACKUP_STRUCT  RTS1_backup = {0u};

    
/*******************************************************************************
* Function Name: RTS1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RTS1_SaveConfig(void) 
{
    RTS1_backup.controlState = RTS1_Control;
}


/*******************************************************************************
* Function Name: RTS1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void RTS1_RestoreConfig(void) 
{
     RTS1_Control = RTS1_backup.controlState;
}


/*******************************************************************************
* Function Name: RTS1_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RTS1_Sleep(void) 
{
    RTS1_SaveConfig();
}


/*******************************************************************************
* Function Name: RTS1_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RTS1_Wakeup(void)  
{
    RTS1_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
