/*******************************************************************************
* File Name: RTS2_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "RTS2.h"

/* Check for removal by optimization */
#if !defined(RTS2_Sync_ctrl_reg__REMOVED)

static RTS2_BACKUP_STRUCT  RTS2_backup = {0u};

    
/*******************************************************************************
* Function Name: RTS2_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RTS2_SaveConfig(void) 
{
    RTS2_backup.controlState = RTS2_Control;
}


/*******************************************************************************
* Function Name: RTS2_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void RTS2_RestoreConfig(void) 
{
     RTS2_Control = RTS2_backup.controlState;
}


/*******************************************************************************
* Function Name: RTS2_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RTS2_Sleep(void) 
{
    RTS2_SaveConfig();
}


/*******************************************************************************
* Function Name: RTS2_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void RTS2_Wakeup(void)  
{
    RTS2_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
