/*******************************************************************************
* \file       TouchButton_Configuration.h
* \version    3.0
*
* \brief
*   This file provides the customizer parameters definitions.
*
* \see CapSense P4 v3.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_CAPSENSE_TouchButton_CONFIGURATION_H)
#define CY_CAPSENSE_TouchButton_CONFIGURATION_H

#include <cytypes.h>

/*******************************************************************************
* Customizer-generated defines
*******************************************************************************/
#define TouchButton_ENABLE                   (1u)
#define TouchButton_DISABLE                  (0u)

/*******************************************************************************
* Creator-global defines
*******************************************************************************/
#ifdef CYIPBLOCK_m0s8csdv2_VERSION
    #define TouchButton_CSDV2                              (1u)
#else
    #define TouchButton_CSDV2                              (0u)
#endif  /* CYIPBLOCK_m0s8csdv2_VERSION */

#if (TouchButton_ENABLE == TouchButton_CSDV2)
    #define TouchButton_2000_MV                            (2000u)

    #ifdef CYDEV_VDDA_MV
        #define TouchButton_CYDEV_VDDA_MV                  (CYDEV_VDDA_MV)
    #else
        #define TouchButton_CYDEV_VDDA_MV                  (CYDEV_VDD_MV)
    #endif  /* CYIPBLOCK_m0s8csdv2_VERSION */

    #define TouchButton_BAD_CONVERSIONS_NUM                (1u)
    #define TouchButton_RESAMPLING_CYCLES_MAX_NUMBER       (1u)
#endif /* (TouchButton_ENABLE == TouchButton_CSDV2) */

/*******************************************************************************
* Enabled Scan Methods
*******************************************************************************/
#define TouchButton_CSD_EN                   (1u)
#define TouchButton_CSX_EN                   (0u)
#define TouchButton_CSD_CSX_EN               (TouchButton_CSD_EN & TouchButton_CSX_EN)
#define TouchButton_CSD2X_EN                 (0u)
#define TouchButton_CSX2X_EN                 (0u)

/*******************************************************************************
* Definitions for number of widgets and sensors
*******************************************************************************/
#define TouchButton_TOTAL_WIDGETS            (1u)
#define TouchButton_TOTAL_CSD_WIDGETS        (1u)
#define TouchButton_TOTAL_CSD_SENSORS        (6u)
#define TouchButton_TOTAL_CSX_WIDGETS        (0u)
#define TouchButton_TOTAL_CSX_NODES          (0u)

/*******************************************************************************
* Total number of CSD sensors + CSX nodes
*******************************************************************************/
#define TouchButton_TOTAL_SENSORS            (TouchButton_TOTAL_CSD_SENSORS + \
                                                   TouchButton_TOTAL_CSX_NODES)

/*******************************************************************************
* Total number of scan slots (used only when dual-channel scan is enabled)
*******************************************************************************/
#define TouchButton_TOTAL_SCAN_SLOTS         (6u)

/*******************************************************************************
* Define widget IDs
*******************************************************************************/
#define TouchButton_MATRIXBUTTONS0_WDGT_ID      (0u)

/*******************************************************************************
* Define sensor IDs
*******************************************************************************/

/* MatrixButtons0 */
#define TouchButton_MATRIXBUTTONS0_COL0_ID      (0u)
#define TouchButton_MATRIXBUTTONS0_COL1_ID      (1u)
#define TouchButton_MATRIXBUTTONS0_COL2_ID      (2u)
#define TouchButton_MATRIXBUTTONS0_ROW0_ID      (3u)
#define TouchButton_MATRIXBUTTONS0_ROW1_ID      (4u)
#define TouchButton_MATRIXBUTTONS0_ROW2_ID      (5u)

/*******************************************************************************
* Enabled widget types
*******************************************************************************/
#define TouchButton_BUTTON_WIDGET_EN         (0u)
#define TouchButton_SLIDER_WIDGET_EN         (0u)
#define TouchButton_MATRIX_WIDGET_EN         (1u)
#define TouchButton_PROXIMITY_WIDGET_EN      (0u)
#define TouchButton_TOUCHPAD_WIDGET_EN       (0u)

#define TouchButton_CSD_MATRIX_WIDGET_EN     (1u)
#define TouchButton_CSD_TOUCHPAD_WIDGET_EN   (0u)

#define TouchButton_CSX_MATRIX_WIDGET_EN     (0u)
#define TouchButton_CSX_TOUCHPAD_WIDGET_EN   (0u)

/*******************************************************************************
* Centroid APIs
*******************************************************************************/
#define TouchButton_CENTROID_EN              (0u)
#define TouchButton_TOTAL_DIPLEXED_SLIDERS   (0u)
#define TouchButton_TOTAL_LINEAR_SLIDERS     (0u)
#define TouchButton_TOTAL_RADIAL_SLIDERS     (0u)
#define TouchButton_TOTAL_TOUCHPADS          (0u)
#define TouchButton_MAX_CENTROID_LENGTH      (0u)

/*******************************************************************************
* Enabled sensor types
*******************************************************************************/
#define TouchButton_REGULAR_SENSOR_EN        (1u)
#define TouchButton_PROXIMITY_SENSOR_EN      (0u)

/*******************************************************************************
* Sensor ganging
*******************************************************************************/
#define TouchButton_CSD_GANGED_SNS_EN        (0u)
#define TouchButton_CSX_GANGED_SNS_EN        (0u)

/*******************************************************************************
* Max number of sensors used among all widgets
*******************************************************************************/
#define TouchButton_MAX_SENSORS_PER_WIDGET   (6u)

/*******************************************************************************
* Total number of all used electrodes (NOT unique)
*******************************************************************************/
#define TouchButton_TOTAL_ELECTRODES         (6u)
/* Obsolete */
#define TouchButton_TOTAL_SENSOR_IOS         TouchButton_TOTAL_ELECTRODES

/*******************************************************************************
* Total number of used physical IOs (unique)
*******************************************************************************/
#define TouchButton_TOTAL_IO_CNT             (6u)

/*******************************************************************************
* Array length for widget status registers
*******************************************************************************/
#define TouchButton_WDGT_STATUS_WORDS        \
                        (((uint8)((TouchButton_TOTAL_WIDGETS - 1u) / 32u)) + 1u)


/*******************************************************************************
* Auto-tuning mode selection
*******************************************************************************/
#define TouchButton_CSD_SS_DIS         (0x00ul)
#define TouchButton_CSD_SS_HW_EN       (0x01ul)
#define TouchButton_CSD_SS_TH_EN       (0x02ul)
#define TouchButton_CSD_SS_HWTH_EN     (TouchButton_CSD_SS_HW_EN | \
                                             TouchButton_CSD_SS_TH_EN)

#define TouchButton_CSD_AUTOTUNE       TouchButton_CSD_SS_HWTH_EN


/*******************************************************************************
* General settings
*******************************************************************************/

#define TouchButton_AUTO_RESET_METHOD_LEGACY (0u)
#define TouchButton_AUTO_RESET_METHOD_SAMPLE (1u)

#define TouchButton_SELF_TEST_EN             (0u)
#define TouchButton_MULTI_FREQ_SCAN_EN       (0u)
#define TouchButton_SENSOR_AUTO_RESET_EN     (0u)
#define TouchButton_SENSOR_AUTO_RESET_METHOD (0u)
#define TouchButton_NUM_CENTROIDS            (1u)
#define TouchButton_OFF_DEBOUNCE_EN          (0u)

/* Define power status of HW IP block after scanning */
#define TouchButton_BLOCK_OFF_AFTER_SCAN_EN  (0u)

/* Define number of scan frequencies */
#if (TouchButton_DISABLE != TouchButton_MULTI_FREQ_SCAN_EN)
    #define TouchButton_NUM_SCAN_FREQS       (3u)
#else
    #define TouchButton_NUM_SCAN_FREQS       (1u)
#endif /* #if (TouchButton_DISABLE != TouchButton_MULTI_FREQ_SCAN_EN) */

/* Data size for thresholds / low baseline reset */
#define TouchButton_SIZE_8BITS               (8u)
#define TouchButton_SIZE_16BITS              (16u)

#define TouchButton_THRESHOLD_SIZE           TouchButton_SIZE_16BITS
typedef uint16 TouchButton_THRESHOLD_TYPE;

#if (TouchButton_AUTO_RESET_METHOD_LEGACY == TouchButton_SENSOR_AUTO_RESET_METHOD)
    #define TouchButton_LOW_BSLN_RST_SIZE        TouchButton_SIZE_8BITS
    typedef uint8 TouchButton_LOW_BSLN_RST_TYPE;
#else
    #define TouchButton_LOW_BSLN_RST_SIZE    (16u)
    typedef uint16 TouchButton_LOW_BSLN_RST_TYPE;
#endif /* #if (TouchButton_AUTO_RESET_METHOD_LEGACY == TouchButton_SENSOR_AUTO_RESET_METHOD) */

/* Coefficient to define touch threshold for proximity sensors */
#define TouchButton_PROX_TOUCH_COEFF         (300u)

/*******************************************************************************
* General Filter Constants
*******************************************************************************/

/* Baseline algorithm options */
#define TouchButton_IIR_BASELINE                 (0u)
#define TouchButton_BUCKET_BASELINE              (1u)

#define TouchButton_BASELINE_TYPE                TouchButton_IIR_BASELINE

/* IIR baseline filter algorithm for regular sensors*/
#define TouchButton_REGULAR_IIR_BL_TYPE          TouchButton_IIR_FILTER_PERFORMANCE

/* IIR baseline coefficients for regular sensors */
#define TouchButton_REGULAR_IIR_BL_N             (1u)
#define TouchButton_REGULAR_IIR_BL_SHIFT         (8u)

/* IIR baseline filter algorithm for proximity sensors*/
#define TouchButton_PROX_IIR_BL_TYPE             TouchButton_IIR_FILTER_PERFORMANCE

/* IIR baseline coefficients for proximity sensors */
#define TouchButton_PROX_IIR_BL_N                (1u)
#define TouchButton_PROX_IIR_BL_SHIFT            (8u)


/* IIR filter constants */
#define TouchButton_IIR_COEFFICIENT_K            (256u)

/* IIR filter type */
#define TouchButton_IIR_FILTER_STANDARD          (1u)
#define TouchButton_IIR_FILTER_PERFORMANCE       (2u)
#define TouchButton_IIR_FILTER_MEMORY            (3u)

/* Regular sensor raw-count filters */
#define TouchButton_REGULAR_RC_FILTER_EN         (0u)
#define TouchButton_REGULAR_RC_IIR_FILTER_EN     (0u)
#define TouchButton_REGULAR_RC_MEDIAN_FILTER_EN  (0u)
#define TouchButton_REGULAR_RC_AVERAGE_FILTER_EN (0u)
#define TouchButton_REGULAR_RC_CUSTOM_FILTER_EN  (0u)

/* Proximity sensor raw-count filters */
#define TouchButton_PROX_RC_FILTER_EN            (0u)
#define TouchButton_PROX_RC_IIR_FILTER_EN        (0u)
#define TouchButton_PROX_RC_MEDIAN_FILTER_EN     (0u)
#define TouchButton_PROX_RC_AVERAGE_FILTER_EN    (0u)
#define TouchButton_PROX_RC_CUSTOM_FILTER_EN     (0u)

/* IIR raw-count filter algorithm for regular sensors */
#define TouchButton_REGULAR_IIR_RC_TYPE          (TouchButton_IIR_FILTER_STANDARD)

/* IIR raw-count filter coefficients for regular sensors */
#define TouchButton_REGULAR_IIR_RC_N             (128u)
#define TouchButton_REGULAR_IIR_RC_SHIFT         (0u)

/* IIR raw-count filter algorithm for proximity sensors*/
#define TouchButton_PROX_IIR_RC_TYPE             (TouchButton_IIR_FILTER_STANDARD)

/* IIR raw-count filter coefficients for proximity sensors */
#define TouchButton_PROX_IIR_RC_N                (128u)
#define TouchButton_PROX_IIR_RC_SHIFT            (0u)

/* Median filter constants */

/* Order of regular sensor median filter */
#define TouchButton_REGULAR_MEDIAN_LEN           (2u)

/* Order of proximity sensor median filter */
#define TouchButton_PROX_MEDIAN_LEN              (2u)

/* Average filter constants*/
#define TouchButton_AVERAGE_FILTER_LEN_2         (2u)
#define TouchButton_AVERAGE_FILTER_LEN_4         (4u)

/* Order of regular sensor average filter */
#define TouchButton_REGULAR_AVERAGE_LEN          (TouchButton_AVERAGE_FILTER_LEN_4)

/* Order of proximity sensor average filter */
#define TouchButton_PROX_AVERAGE_LEN             (TouchButton_AVERAGE_FILTER_LEN_4)


/* Centroid position filters */
#define TouchButton_POS_IIR_FILTER_EN            (0x00u)
#define TouchButton_POS_MEDIAN_FILTER_EN         (0x00u)
#define TouchButton_POS_AVERAGE_FILTER_EN        (0x00u)
#define TouchButton_POS_JITTER_FILTER_EN         (0x00u)
#define TouchButton_CSX_TOUCHPAD_POS_MEDIAN_FILTER_EN (0x00u)

#define TouchButton_POS_IIR_COEFF                (128u)
#define TouchButton_CSX_TOUCHPAD_UNDEFINED       (40u)


/* IDAC options */

/* CSDv1 IDAC gain */
#define TouchButton_IDAC_GAIN_4X                 (4u)
#define TouchButton_IDAC_GAIN_8X                 (8u)

/* CSDv2 IDAC gain */
#define TouchButton_IDAC_GAIN_LOW                (0uL)
#define TouchButton_IDAC_GAIN_MEDIUM             (1uL)
#define TouchButton_IDAC_GAIN_HIGH               (2uL)

#define TouchButton_IDAC_SOURCING                (0u)
#define TouchButton_IDAC_SINKING                 (1u)

/* Shield tank capacitor precharge source */
#define TouchButton_CSH_PRECHARGE_VREF           (0u)
#define TouchButton_CSH_PRECHARGE_IO_BUF         (1u)

/* Shield electrode delay */
#define TouchButton_NO_DELAY                     (0u)
/* CSDv1 */
#define TouchButton_SH_DELAY_50NS                (1u)
#define TouchButton_SH_DELAY_100NS               (2u)
/* CSDv2 */
#define TouchButton_SH_DELAY_5NS                 (1u)
#define TouchButton_SH_DELAY_10NS                (2u)
#define TouchButton_SH_DELAY_20NS                (3u)

/* Inactive sensor connection options */
#define TouchButton_SNS_CONNECTION_GROUND        (0x00000006Lu)
#define TouchButton_SNS_CONNECTION_HIGHZ         (0x00000000Lu)
#define TouchButton_SNS_CONNECTION_SHIELD        (0x00000002Lu)

/* Sense clock selection options */
#if defined(TouchButton_TAPEOUT_STAR_USED)
    #define TouchButton_CSDV2_REF9P6UA_EN            (0u)
#else
    #define TouchButton_CSDV2_REF9P6UA_EN            (0u)
#endif /* defined(TouchButton_TAPEOUT_A_USED) */

#define TouchButton_CLK_SOURCE_DIRECT            (0x00000000Lu)

#define TouchButton_CLK_SOURCE_SSC1              (0x01u)
#define TouchButton_CLK_SOURCE_SSC2              (0x02u)
#define TouchButton_CLK_SOURCE_SSC3              (0x03u)
#define TouchButton_CLK_SOURCE_SSC4              (0x04u)

/* CSDv1 and CSDv2 */
#define TouchButton_CLK_SOURCE_PRS8              (0x05u)
#define TouchButton_CLK_SOURCE_PRS12             (0x06u)
#define TouchButton_CLK_SOURCE_PRSAUTO           (0xFFu)

/* Defines scan resolutions */
#define TouchButton_RES6BIT                      (6u)
#define TouchButton_RES7BIT                      (7u)
#define TouchButton_RES8BIT                      (8u)
#define TouchButton_RES9BIT                      (9u)
#define TouchButton_RES10BIT                     (10u)
#define TouchButton_RES11BIT                     (11u)
#define TouchButton_RES12BIT                     (12u)
#define TouchButton_RES13BIT                     (13u)
#define TouchButton_RES14BIT                     (14u)
#define TouchButton_RES15BIT                     (15u)
#define TouchButton_RES16BIT                     (16u)

/* CSDv2: Initialization switch resistance */
#define TouchButton_INIT_SW_RES_LOW              (0x00000000Lu)
#define TouchButton_INIT_SW_RES_MEDIUM           (0x00000001Lu)
#define TouchButton_INIT_SW_RES_HIGH             (0x00000002Lu)

/* CSDv2: CSD shield switch resistance */
#define TouchButton_SHIELD_SW_RES_LOW            (0x00000000Lu)
#define TouchButton_SHIELD_SW_RES_MEDIUM         (0x00000001Lu)
#define TouchButton_SHIELD_SW_RES_HIGH           (0x00000002Lu)
#define TouchButton_SHIELD_SW_RES_LOW_EMI        (0x00000003Lu)

/*******************************************************************************
* CSD Specific settings
*******************************************************************************/

/* CSD scan method settings */
#define TouchButton_CSD_IDAC_AUTOCAL_EN          (1u)
#define TouchButton_CSD_IDAC_GAIN                (TouchButton_IDAC_GAIN_4X)
#define TouchButton_CSD_SHIELD_EN                (0u)
#define TouchButton_CSD_SHIELD_TANK_EN           (0u)
#define TouchButton_CSD_CSH_PRECHARGE_SRC        (TouchButton_CSH_PRECHARGE_VREF)
#define TouchButton_CSD_SHIELD_DELAY             (TouchButton_NO_DELAY)
#define TouchButton_CSD_TOTAL_SHIELD_COUNT       (0u)
#define TouchButton_CSD_SCANSPEED_DIVIDER        (2u)
#define TouchButton_CSD_COMMON_SNS_CLK_EN        (0u)
#define TouchButton_CSD_SNS_CLK_SOURCE           (TouchButton_CLK_SOURCE_PRSAUTO)
#define TouchButton_CSD_SNS_CLK_DIVIDER          (2u)
#define TouchButton_CSD_INACTIVE_SNS_CONNECTION  (TouchButton_SNS_CONNECTION_GROUND)
#define TouchButton_CSD_IDAC_COMP_EN             (1u)
#define TouchButton_CSD_IDAC_CONFIG              (TouchButton_IDAC_SOURCING)
#define TouchButton_CSD_RAWCOUNT_CAL_LEVEL       (85u)
#define TouchButton_CSD_DUALIDAC_LEVEL           (50u)
#define TouchButton_CSD_PRESCAN_SETTLING_TIME    (5u)
#define TouchButton_CSD_SNSCLK_R_CONST           (1000u)
#define TouchButton_CSD_VREF_MV                  (1200u)

/* CSD settings - CSDv2 */
#define TouchButton_CSD_DEDICATED_IDAC_COMP_EN   (1u)
#define TouchButton_CSD_AUTO_ZERO_EN             (0u)
#define TouchButton_CSD_AUTO_ZERO_TIME           (15Lu)
#define TouchButton_CSD_NOISE_METRIC_EN          (0u)
#define TouchButton_CSD_NOISE_METRIC_TH          (1Lu)
#define TouchButton_CSD_INIT_SWITCH_RES          (TouchButton_INIT_SW_RES_MEDIUM)
#define TouchButton_CSD_SHIELD_SWITCH_RES        (TouchButton_SHIELD_SW_RES_MEDIUM)
#define TouchButton_CSD_GAIN                     (31Lu)


/*******************************************************************************
* CSX Specific settings
*******************************************************************************/

/* CSX scan method settings */
#define TouchButton_CSX_SCANSPEED_DIVIDER        (2u)
#define TouchButton_CSX_COMMON_TX_CLK_EN         (0u)
#define TouchButton_CSX_TX_CLK_SOURCE            (TouchButton_CLK_SOURCE_DIRECT)
#define TouchButton_CSX_TX_CLK_DIVIDER           (20u)
#define TouchButton_CSX_MAX_FINGERS              (1u)
#define TouchButton_CSX_MAX_LOCAL_PEAKS          (5u)
#define TouchButton_CSX_IDAC_AUTOCAL_EN          (0u)
#define TouchButton_CSX_IDAC_BITS_USED           (8u)
#define TouchButton_CSX_RAWCOUNT_CAL_LEVEL       (40u)
#define TouchButton_CSX_IDAC_GAIN                (TouchButton_IDAC_GAIN_4X)
#define TouchButton_CSX_SKIP_OVSMPL_SPECIFIC_NODES (0u)
#define TouchButton_CSX_MULTIPHASE_TX_EN         (0u)
#define TouchButton_CSX_MAX_TX_PHASE_LENGTH      (0u)

/* CSX settings - CSDv2 */
#define TouchButton_CSX_AUTO_ZERO_EN             (0u)
#define TouchButton_CSX_AUTO_ZERO_TIME           (15u)
#define TouchButton_CSX_NOISE_METRIC_EN          (0u)
#define TouchButton_CSX_NOISE_METRIC_TH          (1u)
#define TouchButton_CSX_INIT_SWITCH_RES          (TouchButton_INIT_SW_RES_MEDIUM)


/*******************************************************************************
* Global Parameter Definitions
*******************************************************************************/

/* RAM Global Parameters Definitions */
#define TouchButton_CONFIG_ID                   (0x9616u)
#define TouchButton_DEVICE_ID                   (0x0460u)
#define TouchButton_CSD0_CONFIG                 (0x0000u)


/***************************************************************************//**
* MatrixButtons0 initialization values for FLASH data structure
*******************************************************************************/
#define TouchButton_MATRIXBUTTONS0_STATIC_CONFIG (1u)
#define TouchButton_MATRIXBUTTONS0_NUM_COLS     (3u)
#define TouchButton_MATRIXBUTTONS0_NUM_ROWS     (3u)

/***************************************************************************//**
* MatrixButtons0 initialization values for RAM data structure
*******************************************************************************/
#define TouchButton_MATRIXBUTTONS0_RESOLUTION   (TouchButton_RES12BIT)
#define TouchButton_MATRIXBUTTONS0_FINGER_TH    (100u)
#define TouchButton_MATRIXBUTTONS0_NOISE_TH     (40u)
#define TouchButton_MATRIXBUTTONS0_NNOISE_TH    (40u)
#define TouchButton_MATRIXBUTTONS0_HYSTERESIS   (10u)
#define TouchButton_MATRIXBUTTONS0_ON_DEBOUNCE  (3u)
#define TouchButton_MATRIXBUTTONS0_LOW_BSLN_RST (30u)
#define TouchButton_MATRIXBUTTONS0_BSLN_COEFF   (100u)
#define TouchButton_MATRIXBUTTONS0_IDAC_MOD0    (32u)
#define TouchButton_MATRIXBUTTONS0_ROW_IDAC_MOD0 (32u)
#define TouchButton_MATRIXBUTTONS0_SNS_CLK      (4u)
#define TouchButton_MATRIXBUTTONS0_ROW_SNS_CLK  (4u)
#define TouchButton_MATRIXBUTTONS0_SNS_CLK_SOURCE (0u)
#define TouchButton_MATRIXBUTTONS0_ROW_SNS_CLK_SOURCE (0u)
#define TouchButton_MATRIXBUTTONS0_FINGER_CAP   (160u)
#define TouchButton_MATRIXBUTTONS0_SIGPFC       (0u)
#define TouchButton_MATRIXBUTTONS0_POS_COL      (0xFFu)
#define TouchButton_MATRIXBUTTONS0_POS_ROW      (0xFFu)
#define TouchButton_MATRIXBUTTONS0_POS_SNS_ID   (0u)

/* RAM Sensor Parameters Definitions */
#define TouchButton_MATRIXBUTTONS0_COL0_IDAC_COMP0 (32u)
#define TouchButton_MATRIXBUTTONS0_COL1_IDAC_COMP0 (32u)
#define TouchButton_MATRIXBUTTONS0_COL2_IDAC_COMP0 (32u)
#define TouchButton_MATRIXBUTTONS0_ROW0_IDAC_COMP0 (32u)
#define TouchButton_MATRIXBUTTONS0_ROW1_IDAC_COMP0 (32u)
#define TouchButton_MATRIXBUTTONS0_ROW2_IDAC_COMP0 (32u)


/*******************************************************************************
* ADC Specific Macros
*******************************************************************************/
#define TouchButton_ADC_RES8BIT                  (8u)
#define TouchButton_ADC_RES10BIT                 (10u)

#define TouchButton_ADC_EN                       (0u)
#define TouchButton_ADC_TOTAL_CHANNELS           (1u)
#define TouchButton_ADC_RESOLUTION               (TouchButton_ADC_RES10BIT)
#define TouchButton_ADC_AMUXB_INPUT_EN           (0u)
#define TouchButton_ADC_SELECT_AMUXB_CH          (0u)
#define TouchButton_ADC_AZ_EN                    (1Lu)
#define TouchButton_ADC_AZ_TIME                  (5u)
#define TouchButton_ADC_VREF_MV                  (2133u)
#define TouchButton_ADC_GAIN                     (17Lu)
#define TouchButton_ADC_IDACVAL                  (27u)

#endif /* CY_CAPSENSE_TouchButton_CONFIGURATION_H */


/* [] END OF FILE */
