/***************************************************************************//**
* \file     TouchButton_Filter.h
* \version  3.0
*
* \brief    This file contains the definitions for all firmware filters 
*           implementation.
*
* \see      CapSense P4 v3.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_CAPSENSE_TouchButton_FILTER_H)
#define CY_CAPSENSE_TouchButton_FILTER_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"
    
#include "TouchButton_Structure.h"    
#include "TouchButton_Configuration.h"    
 
  
/***************************************
* Function Prototypes 
***************************************/ 

/*******************************************************************************
* LOW LEVEL API 
*******************************************************************************/
/**
* \if SECTION_CAPSENSE_LOW_LEVEL
* \addtogroup group_capsense_low_level
* \{
*/
    
cystatus TouchButton_UpdateAllBaselines(void);
cystatus TouchButton_UpdateWidgetBaseline(uint32 widgetId);
cystatus TouchButton_UpdateSensorBaseline(
                             uint32 widgetId, uint32 sensorId);

void TouchButton_InitializeAllBaselines(void);    
void TouchButton_InitializeWidgetBaseline(uint32 widgetId);
void TouchButton_InitializeSensorBaseline(uint32 widgetId, uint32 sensorId);

/** \}
* \endif */


/*******************************************************************************
* Function Prototypes - internal functions
*******************************************************************************/
/**
* \if SECTION_CAPSENSE_INTERNAL
* \addtogroup group_capsense_internal
* \{
*/

void TouchButton_FtInitialize(void);

#if (TouchButton_CSD_AUTOTUNE & TouchButton_CSD_SS_TH_EN)
    void TouchButton_RunNoiseEnvelope(uint32 widgetId, uint32 sensorId);
    void TouchButton_InitializeNoiseEnvelope(uint32 widgetId, uint32 sensorId);
#endif /* #if TouchButton_CSD_AUTOTUNE & TouchButton_CSD_SS_TH_EN */

#if (TouchButton_REGULAR_RC_IIR_FILTER_EN || TouchButton_PROX_RC_IIR_FILTER_EN)
    void TouchButton_InitializeIIR(uint32 widgetId, uint32 sensorId);
    void TouchButton_RunIIR(uint32 widgetId, uint32 sensorId);
#endif /* (TouchButton_REGULAR_RC_IIR_FILTER_EN || TouchButton_PROX_RC_IIR_FILTER_EN) */

#if (TouchButton_REGULAR_RC_MEDIAN_FILTER_EN || TouchButton_PROX_RC_MEDIAN_FILTER_EN)
    void TouchButton_InitializeMedian(uint32 widgetId, uint32 sensorId);
    void TouchButton_RunMedian(uint32 widgetId, uint32 sensorId);
#endif /* (TouchButton_REGULAR_RC_MEDIAN_FILTER_EN || TouchButton_PROX_RC_MEDIAN_FILTER_EN) */

#if (TouchButton_REGULAR_RC_AVERAGE_FILTER_EN || TouchButton_PROX_RC_AVERAGE_FILTER_EN)
    void TouchButton_InitializeAverage(uint32 widgetId, uint32 sensorId);
    void TouchButton_RunAverage(uint32 widgetId, uint32 sensorId);
#endif /* (TouchButton_REGULAR_RC_AVERAGE_FILTER_EN || TouchButton_PROX_RC_AVERAGE_FILTER_EN) */

void TouchButton_FtInitializeBaseline(TouchButton_RAM_SNS_STRUCT *ptrSensor, uint32 wdType);
cystatus TouchButton_FtUpdateBaseline(
                            TouchButton_RAM_WD_BASE_STRUCT *ptrWidgetRam,
                            TouchButton_RAM_SNS_STRUCT *ptrSensor, 
                            uint32 wdType);

#if (TouchButton_POS_MEDIAN_FILTER_EN || TouchButton_REGULAR_RC_MEDIAN_FILTER_EN || TouchButton_PROX_RC_MEDIAN_FILTER_EN)
uint32 TouchButton_FtMedian(uint32 x1, uint32 x2, uint32 x3);
#endif /*TouchButton_POS_MEDIAN_FILTER_EN || TouchButton_REGULAR_RC_MEDIAN_FILTER_EN || TouchButton_PROX_RC_MEDIAN_FILTER_EN*/

uint32 TouchButton_FtIIR1stOrder(uint32 input, uint32 prevOutput, uint32 n, uint32 shift);

#if (TouchButton_POS_JITTER_FILTER_EN)
    uint32 TouchButton_FtJitter(uint32 input, uint32 prevOutput);
#endif /* TouchButton_POS_JITTER_FILTER_EN */

void TouchButton_FtInitializeBaselineChannel(TouchButton_RAM_SNS_STRUCT *ptrSensor, uint32 wdType, uint32 channel); 

#if (TouchButton_REGULAR_RC_FILTER_EN || TouchButton_PROX_RC_FILTER_EN)
    void TouchButton_FtRunEnabledFilters(uint32 widgetId, uint32 sensorId);
    void TouchButton_FtRunEnabledFiltersInternal(TouchButton_PTR_FILTER_VARIANT ptrFilterHistObj, 
                                                      TouchButton_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
#endif /* (TouchButton_REGULAR_RC_FILTER_EN || TouchButton_PROX_RC_FILTER_EN) */


#if (TouchButton_REGULAR_RC_IIR_FILTER_EN || TouchButton_PROX_RC_IIR_FILTER_EN)
    void TouchButton_InitializeIIRInternal(TouchButton_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                  TouchButton_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
    void TouchButton_RunIIRInternal(TouchButton_PTR_FILTER_VARIANT ptrFilterHistObj,
                                           TouchButton_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
#endif /* (TouchButton_REGULAR_RC_IIR_FILTER_EN || TouchButton_PROX_RC_IIR_FILTER_EN) */

#if (TouchButton_REGULAR_RC_MEDIAN_FILTER_EN || TouchButton_PROX_RC_MEDIAN_FILTER_EN)
    void TouchButton_InitializeMedianInternal(TouchButton_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                     TouchButton_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);    
    void TouchButton_RunMedianInternal(TouchButton_PTR_FILTER_VARIANT ptrFilterHistObj,
                                              TouchButton_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);    
#endif /* (TouchButton_REGULAR_RC_MEDIAN_FILTER_EN || TouchButton_PROX_RC_MEDIAN_FILTER_EN) */

#if (TouchButton_REGULAR_RC_AVERAGE_FILTER_EN || TouchButton_PROX_RC_AVERAGE_FILTER_EN)
    void TouchButton_InitializeAverageInternal(TouchButton_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                      TouchButton_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
    void TouchButton_RunAverageInternal(TouchButton_PTR_FILTER_VARIANT ptrFilterHistObj,
                                               TouchButton_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
#endif /* (TouchButton_REGULAR_RC_AVERAGE_FILTER_EN || TouchButton_PROX_RC_AVERAGE_FILTER_EN) */


/** \}
* \endif */

/***************************************
* Initial Parameter Constants
***************************************/
#define NOISE_ENVELOPE_SHIFT                        (0x02u)
#define NOISE_ENVELOPE_RUN_DIFF_SHIFT               (0x03u)
#define NOISE_ENVELOPE_SIGN_REG                     (0x0Fu)
#define NOISE_ENVELOPE_SIGN_REG_SHIFT               (0x01u)
#define NOISE_ENVELOPE_RESET_COUNTER                (0x0Au)
#define NOISE_ENVELOPE_4_TIMES                      (0x02u)

#endif /* End CY_CAPSENSE_TouchButton_FILTER_H */


/* [] END OF FILE */
